@@ -4,12 +4,12 @@ import asyncio
 import ipaddress
 import os
 from dataclasses import dataclass
+from pathlib import Path
 
 from aiohttp import ClientConnectorError, ClientSession, ClientTimeout, streamer, web
 
 from fluxvault.helpers import get_app_and_component_name
 from fluxvault.log import log
-from pathlib import Path
 
 
 @dataclass
@@ -176,8 +176,11 @@ class FluxAgentRegistrar:
                 body="Unauthorized",
                 status=403,
             )
-        remote_component, remote_app = get_app_and_component_name(request.remote)
+        _, remote_app = get_app_and_component_name(request.remote)
         if remote_app != self.app_name:
+            log.warn(
+                f"Request from {request.remote} denied. {remote_app} does not match local: {self.app_name}"
+            )
             return web.Response(
                 body="Unauthorized",
                 status=403,
